This module defines the Preprocessor trait, which allows for generalized data to be created
about BinaryObjects prior to being run through the ScanModules to avoid duplicate
processing. For more information on how to contribute your own preprocessor, see
docs/contributing/PREPROCESSORS.md.
Traits
- Preprocessor
- A trait that defines the necessary functions of a
Preprocessor. APreprocessoris a modular component that has no dependencies on other preprocessors. It creates a HashMap ofStrings mapped to otherStrings that can then be accessed by the scan modules. For more information on how to contribute your own preprocessor, seedocs/contributing/PREPROCESSORS.md.