pub struct ExifScanModule;Trait Implementations
Sourceimpl ScanModule for ExifScanModule
impl ScanModule for ExifScanModule
Sourcefn scan(&self, scan_object: &ScanObject) -> Result<Vec<Finding>, ArmorlibError>
fn scan(&self, scan_object: &ScanObject) -> Result<Vec<Finding>, ArmorlibError>
Scan the given
scan_object and return either a vector of Findings or, in case of an
error, an ArmorlibError.Sourcefn info(&self) -> (&'static str, &'static str)
fn info(&self) -> (&'static str, &'static str)
Returns a tuple containing the name and description of the scan module.
Sourcefn required_preprocessors(&self) -> Vec<&'static str>
fn required_preprocessors(&self) -> Vec<&'static str>
Return a
Vec of &'static strs indicating the preprocessors that the scan module relies
on for running. These names should match the name provided by the processor in its name()
function.Sourcefn subscribed_filetypes(&self) -> Option<Vec<&'static str>>
fn subscribed_filetypes(&self) -> Option<Vec<&'static str>>
Returns an
Option<Vec<&'static str>> of the filetypes that the scan module is subscribed
to. If a scan module subscribes to a filetype, it will only be run if the data is detected
to be of any of the subscribed filetypes. If a scan module’s subscribed_filetypes()
function returns None (default), it will be run for every filetype. Read moreSourcefn name(&self) -> &'static str
fn name(&self) -> &'static str
Returns a
&'static str of the name of the scan module. This information is drawn from
the information provided by info() in its default implementation.Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
Returns a
&'static str of the description of the scan module. This information is drawn
from the information provided by info() in its default implementation.Auto Trait Implementations
impl Freeze for ExifScanModule
impl RefUnwindSafe for ExifScanModule
impl Send for ExifScanModule
impl Sync for ExifScanModule
impl Unpin for ExifScanModule
impl UnwindSafe for ExifScanModule