Module scan_object

Module scan_object 

This module defines the ScanObject, which represents a BinaryObject that has been preprocessed. The ScanObject struct defined in this module is accessible in the root namespace as armorlib::ScanObject.

Structs

ScanObject
A struct that represents a BinaryObject (with associated filetype) that has been preprocessed and therefore contains metadata. This is the object that is passed to ScanModules.